Description: マイページサービス登録
Keywords: 賃貸・売買,ハウスドゥ！,マイページサービス登録

## マイページサービス新規登録

ご利用頂きまして、ありがとうございます。
マイページを登録することで、希望の検索条件やお気に入り物件の保存など、より便利なサービスがご利用になれます。

1. 1.お問合せ内容の入力
2. 2.内容確認
3. 3.完了

### ご希望の物件情報をお聞かせください。

必須物件種別とご希望価格 （複数選択可） | 新築戸建 ～ 中古戸建 ～ 新築マンション ～ 中古マンション ～ 土地 ～ 収益物件・事業用 ～
任意ご希望の条件・ご要望 |

都道府県・市区町村を選択してください。取扱い物件のある店舗が全て表示されます。

必須ご希望都道府県 |
必須ご希望市区町村 |

必須店舗を選択して下さい （複数選択可） | 対象のエリアを得意とする店舗は存在しません。

### お客様について

必須メールアドレス | ※ログインユーザー名となります。
必須メールアドレス確認 |
必須お名前 | 姓 名
必須フリガナ | セイ メイ
必須電話番号 | - -
必須ご住所 | 〒 - ※ 郵便番号から住所を自動入力できます。 例○○１−１−１○○アパート １階（マンション・アパート名、号室等もご記入ください。）
必須ご希望のご連絡方法 | 郵便 電話 FAX Eメール
必須FAX※「ご希望の連絡方法」で 「FAX」選択時は必須 | - -

### アンケートにご協力をお願いいたします

任意ハウスドゥ！を知ったきっかけを お聞かせください。 | インターネット検索 チラシ TVCM ラジオCM 看板 不動産検索ポータル（HOME'S/at home/SUUMO/Yahoo!不動産 等） 紹介 その他

### プライバシーポリシーをご確認ください

当サイトは一般ユーザーの方を対象としており、同業他社様のご登録は固くお断りいたします。
マイページサービスに登録されましても内容を削除させて頂くことがございます。あらかじめご了承下さい。